@@ -6,7 +6,7 @@ from pathlib import Path
 import yaml
 from typing import Union
 
-from steam_sdk.data.DataSettings import DataSettingsSTEAM
+from steam_sdk.data.DataSettings import DataSettings
 from steam_sdk.builders.BuilderModel import BuilderModel
 from steam_sdk.data.DataAnalysis import DataAnalysis, ModifyModel
 from steam_sdk.drivers.DriverFiQuS import DriverFiQuS
@@ -35,7 +35,7 @@ class AnalysisSTEAM:
         self.relative_path_settings = Path(relative_path_settings).resolve()
         self.verbose = verbose
         self.data_analysis = None  # object containing the information read from the analysis input file
-        self.settings      = DataSettingsSTEAM()  # object containing the settings acquired during initialization
+        self.settings      = DataSettings()  # object containing the settings acquired during initialization
         self.library_path  = None
         self.output_path   = None
         self.temp_path     = None
@@ -217,7 +217,7 @@ class AnalysisSTEAM:
             print('Making model object named {}'.format(str(step.model_name)))
         ## Assuming the steam-models directory structure if 'steam-models' or model_library found at the end of library path.
         # Else assuming library path directs straight to the model
-        if (str(self.library_path).endswith('steam-models')) or (str(self.library_path).endswith('model_library')):
+        if (str(self.library_path).endswith('steam_models')) or (str(self.library_path).endswith('steam-models')) or (str(self.library_path).endswith('model_library')):
             file_model_data = os.path.join(self.library_path, step.case_model + 's', step.file_model_data, 'input', 'modelData_' + step.file_model_data + '.yaml')
         else:
             file_model_data = os.path.join(self.library_path,'modelData_' + step.file_model_data + '.yaml')
