@@ -1,6 +1,6 @@
 from pydantic import BaseModel
 from typing import (List, Union, Literal, Dict)
-from steam_sdk.data.DataSettings import DataSettingsSTEAM
+from steam_sdk.data.DataSettings import DataSettings
 
 
 ############################
@@ -146,7 +146,7 @@ class DataAnalysis(BaseModel):
     '''
 
     GeneralParameters: General = General()
-    PermanentSettings: DataSettingsSTEAM = DataSettingsSTEAM()
+    PermanentSettings: DataSettings = DataSettings()
     WorkingFolders: WorkingFolders = WorkingFolders()
     AnalysisStepDefinition: Dict[str, Union[MakeModel, ModifyModel, ModifyModelMultipleVariables, SetUpFolder, AddAuxiliaryFile, RunSimulation, PostProcess]] = {}
     AnalysisStepSequence: List[str] = []  # Here the analysis steps are defined, in execution order. Names must be defined in AnalysisStepDefinition. Repetitions ARE allowed.
