@@ -1,7 +1,7 @@
 from pydantic import BaseModel
 from typing import Dict
 from steam_sdk.data.DataAnalysis import WorkingFolders
-from steam_sdk.data.DataSettings import DataSettingsSTEAM
+from steam_sdk.data.DataSettings import DataSettings
 
 ### SUB-SUB-LEVEL
 class interface(BaseModel):
@@ -51,9 +51,9 @@ class STEAMmodel(BaseModel):
     case_model: str = None
 
 ############# Main Level ########
-class DataDAKOTA(BaseModel):
+class DataDakota(BaseModel):
     DAKOTA_analysis: DAKOTA_analysis = DAKOTA_analysis()
-    PermanentSettings: DataSettingsSTEAM = DataSettingsSTEAM()
+    PermanentSettings: DataSettings = DataSettings()
     WorkingFolders: WorkingFolders = WorkingFolders()
     STEAMmodel: STEAMmodel = STEAMmodel()
 
