@@ -4,8 +4,7 @@ import ruamel.yaml
 
 from steam_sdk.builders.BuilderFiQuS import BuilderFiQuS
 from steam_sdk.data import DataFiQuS as dF
-from steam_sdk.parsers.dict_to_yaml import dict_to_yaml
-
+from steam_sdk.parsers.ParserYAML import dict_to_yaml
 
 class ParserFiQuS:
     """
@@ -30,11 +29,11 @@ class ParserFiQuS:
 
         with open(file_name + '.geom', "r") as stream:
             dictionary_yaml = ruamel.yaml.safe_load(stream)
-            self.builder_FiQuS.data_FiQuS = dF.FiQuSGeometry(**dictionary_yaml)
+            self.builder_FiQuS.data_FiQuS = dF.MultipoleGeometry(**dictionary_yaml)
 
         with open(file_name + '.set', "r") as stream:
             dictionary_yaml = ruamel.yaml.safe_load(stream)
-            self.builder_FiQuS.data_FiQuS = dF.FiQuSSettings(**dictionary_yaml)
+            self.builder_FiQuS.data_FiQuS = dF.MultipoleSettings(**dictionary_yaml)
 
         if verbose:
             print('File {} was loaded.'.format(file_name))
